/* Functions exported from file ./mapkit/src/err_sim.c */

#ifndef ERR_POS_P_H
#define ERR_POS_P_H


/**************
  sets the accuracy model on the 
  robot position
  ec_lin = percent of the linear displacement:
           (straight line)
  ec_rot = percent of rotation.
  ec_ang_tr = degrees / meter deviation
****************/

void SetAccuracyMove(double ec_lin, double ec_rot, double ec_ang_tr);


/*********************
  computes the new error variance from 
  - the previous error variance Vpos[6] (3*3 symetrical
    matrix)
    defined in ../include/rob_pos.h

  - the previous robot position computed
    in Glob_pos[4] deifined in 
    defined in ../include/rob_pos.h

  - the command vector parameter c_trans and c_rot. 



  -1 : applies a model of uncertainty computing 
           the variance matrix Vcom[3] (2*2 symetrical
	   matrix); Update the static global 
	   variable Vcom;

       __Accuracy_model(c_trans,c_rot);

  -2 : computes the effect of the error due to the 
       command, assuming a perfect knowledge on the
       previous position of the robot : static global
       variable Vpos_com[6] (3*3).

       __Calc_Vpos_com(c_trans,c_rot)

  -3 : computes the effect on the new position  due
       to the previous error on the robot position
       assuming a perfect command: static global
       variable Vpos_prev[6] (3*3)
       
       __Calc_Vpos_prev(c_trans,c_rot)

  -4 : Adds the 2 components to computes V pos[6];
       __mxs_plus(Vpos_prev,Vpos_com,Vpos,3,3);

***********************************/

void integrate_error(double c_trans,double c_rot);



#endif /* ERR_POS_P_H */
