/* ----------------------------------------------------------------------
   PROTOTYPES of EXTERNAL FUNCTIONS OF odom_sim.c 
   ---------------------------------------------------------------------- */

#ifndef ODOMETER_H
#define ODOMETER_H

extern void init_encoders(double *xp);

/*** set the encoder values from the robot's reading **/
/** the state vector is assumed already transformed in inch and radians (doubles) ***/

extern void set_encoders(double *pos, double *var);

/***********
  init location from an array of 3 doubles defining the new position
  of x,y and the STEERING angle ; 
  the location for the turret is set to steering + rob_enc[3] - rob_enc[4].
  
  One should use this function when the local data used for relocation
  was expressed in the steering coordinate system

  Recomputes Loc2Abs and its variance.
  If you don't want to deal with the variance, put vxp = null
  In any case, zeroes the variance on the robot side.
***********/

extern void init_location_st(double *x, double *vxp);


/***********
  init location from an array of 3 doubles defining the new position
  of x,y and the TURRET angle; 
  the location for the steering is set to turret + rob_enc[2] - rob_enc[3].
  One should use this function when the local data used for relocation
  was expressed in the turret coordinate system

  Recomputes Loc2Abs and its variance.
  If you don't want to deal with the variance, put vxp = null
  In any case, zeroes the variance on the robot side.
***********/

extern void init_location_tu(double *x,double *vxp);

extern void init_tr_st(double *x,double *vtr);

 
/***********
  computes  the current location error into 
  the array Vpos;
****************/

extern void get_location_err(void);

/** functions in odom_funct.c **/



/**************
  compute the transformation from
  the absolute location and the robot encoders.

  Warning: abs_pos and tr must be different arrays
**************/

extern void CalcTransf(double *abs_pos,double *vabs_pos,double *xrob,double *tr,double *vtr);


/**************
  compute the transformation from
  the absolute location and the robot encoders.
  Same as above but without variance computation.

  Warning: abs_pos and tr must be different arrays
**************/

extern void CalcTransfNp(double *abs_pos,double *xrob,double *tr);


extern void Calc_abs_pos(double *xrob,double *vrob,double *tr,double *vtr,double *abs,double *vabs);

extern void Calc_abs_pos_np(double *xrob,double *tr,double *abs);


/*** functions in err_sim.c **/

extern void integrate_error(double c_trans,double c_rot);

extern void Init_variance(void);

extern void GetAbsPos ( double *enc, double *g_pos );



#endif /* ODOMETER_H */
